@@ -3,7 +3,8 @@ from django.conf.urls.defaults import patterns, url
 from insight.views import set_origin_code
 
 
-urlpatterns = patterns('',
+urlpatterns = patterns(
+    '',
     # tracking url
     url(
         r'^i/(?P<code>[\w]+)/$',
